Academic Review Tool (ART)
===

The Academic Review Tool (ART) is a package for performing academic reviews and bibliometric analyses in Python. It offers capabilities for discovering, retrieving, and analysing academic literature at scale. ART accesses records from Crossref, Web of Science, Scopus, Orcid, and more.

## Table of Contents

[TOC]


## **Description**

ART is a package for performing academic reviews and bibliometric analyses in Python. It offers capabilities for discovering, retrieving, and analysing academic literature at scale.

The tool's functionalities include:
* Searching for works using keywords, dates, authors, funders, and other information.
* Searching for authors and their works.
* Searching for funders and their funded works.
* Looking up DOIs, ISBNs, ISSNs, ORCID IDs, URLs, and other unique identifiers.
* Scraping academic repositories and websites.
* Citation and weblink crawling.
* Citation and coauthorship analysis.
* Generating networks representing:
    * Citations and references
    * Coauthors
    * Cofunders
    * And more...

ART uses the following APIs:
* Crossref
* Web of Science (Starter API)
* Scopus
* ORCID
* Geopy / Nominatim

The tool is object-oriented. It leverages Pandas, Numpy, iGraph, and other standard Python libraries for ease of use. 

ART can read and write your results to a large variety of file types (e.g. .xlsx, .csv, .txt, .json, .graphML).

## Installation

To install using PyPi, run the following code in your command interface:
```bash
pip install academic-review-tool
```

## Beginners Guide




## Appendix and FAQ

:::info
Leave a comment!
:::

###### tags: `Academic reviews` `Bibliometrics` `Python`


